pub enum Verdict<S, P = Accept> {
Proceed(P),
Stop(S),
}Expand description
The final result of packet processing at a given filtering hook.
The type parameters depend on the hook:
Sis returned withStopand specifies the reason for stopping or additional actions to take.Pis returned withProceedand carries context for further processing (e.g. NAT results).
Variants
Proceed(P)
The packet should continue traversing the stack.
Stop(S)
The packet processing should be stopped. The argument specifies additional actions to take.